# All keywords are interpreted case insensitively

# logfile: name of the logfile (absolute or relative to $HOME)
# logfile: etc/remailer.log

# loglevel: 0: debug, 1: commands, 2: default
# loglevel: 2

# debug: true has the same effect as the --debug or -d flag
# debug: false

# noMail: if true no mail is sent (same effect as the --no-mail flag)
# noMail: true

# keepfiles keeps the files, and requires sufix nr of files to write
keepfiles: 1

# tmp: location tmp dir (absolute or relative to $HOME)
#tmp: tmp 

# The Reply-To header (one line, no (double) quotes)
#replyTo:    Fill in your reply-to <somebody@somewhere.org>
replyTo: Frank <frank@localhost>

recipient: frank

# reencrypt to which address(es)? (multiple members OK)
member: user1@mailhost.org
member: user2@mailhost.org

    # clear-text mail is not handled.
#clear-text: rejected       
    # any clear-text is accepted
clear-text: accepted
    # clear-text is accepted from configured envelope addresses
#clear-text: envelope       

# multiple envelope addresses may be specified: addresses from where
# clear-text e-mail is accepted if 'clear-text: envelope' was specified

    # accept all member addresses as envelope addresses
# envelope:  members        
    # to accept clear-text email from address@domain:
# envelope: address@domain  

# signature setting ignored for clear-text mail
# signature specs may be:   absent: none required, 
#                           required: the encrypted file must have been signed
#                           good: the signature must have been recognized as
#                                 good
# signature:  good
signature:  required

# Where will the reencrypted mail be sent to (multiple recipients OK)?
#
#   all members receive the reencrypted mail
# recipient:  members
#
#   add a specific recipient
# recipient:  frank@localhost
#
#   send the reencrypted mail to some mailing list
# recipient:  mailing.list@somehost.org

# Add x-headers to distributed e-mail
x-headers


